@@ -5,7 +5,7 @@
 ;; Author: Matthew Carter <m@ahungry.com>
 ;; Maintainer: Matthew Carter <m@ahungry.com>
 ;; URL: https://github.com/ahungry/color-theme-ahungry
-;; Version: 1.0.4
+;; Version: 1.0.5
 ;; Keywords: ahungry palette color theme emacs color-theme deftheme
 ;; Package-Requires: ((emacs "24"))
 
@@ -36,6 +36,9 @@
 
 ;;; News:
 
+;;;; Changes since 1.0.4:
+;; - Don't circumvent normal autoloads functionality, use the comment load method
+
 ;;;; Changes since 1.0.3:
 ;; - Manually include an autoloads file to make sure
 ;;   custom-theme-load-path is filled out
@@ -186,6 +189,12 @@
    '(red "#ffffff"))
   )
 
+;;;###autoload
+(when (and load-file-name (boundp 'custom-theme-load-path))
+ (add-to-list
+      'custom-theme-load-path
+      (file-name-as-directory (file-name-directory load-file-name))))
+
 (provide-theme 'ahungry)
 
 ;;; ahungry-theme.el ends here
